Stan Math Library: stan/math/fwd/scal/fun/binary_log_loss.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

binary_log_loss.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_BINARY_LOG_LOSS_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_BINARY_LOG_LOSS_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/binary_log_loss.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12 template <typename T>
13 inline
14 fvar<T>
15 binary_log_loss(const int y, const fvar<T>& y_hat) {
16 using stan::math::binary_log_loss;
17
18 if (y)
19 return fvar<T>(binary_log_loss(y, y_hat.val_),
20 -y_hat.d_ / y_hat.val_);
21 else
22 return fvar<T>(binary_log_loss(y, y_hat.val_),
23 y_hat.d_ / (1.0 - y_hat.val_));
24 }
25 }
26 }
27 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::binary_log_loss
fvar< T > binary_log_loss(const int y, const fvar< T > &y_hat)
Definition: binary_log_loss.hpp:15
binary_log_loss.hpp
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.